#!/bin/bash

##################################################################
#
# Migrate SLES-11-SP3-for-VMware to SLES-11-SP3
#
# Copyright (C) 2013 SUSE Linux Products GmbH
#
##################################################################


# Check if root runs this script
if [[ $EUID -ne 0 ]]; then
   echo -e "\nThis script must be run as root\n" 1>&2
   exit 1
fi

echo -e "\nThis script will migrate your installed\n
\tSUSE Linux Enterprise Server 11 SP3 for VMware\n
to a\n
\tSUSE Linux Enterprise Server 11 SP3.\n
You need the registration keys for SUSE Linux Enterprise Server 11 SP3
and all installed Add-On products. All changes to the channel setup
will go lost during this process.
Do you want to continue? [y/n]\n"

start_migration() {

    read ANSWER

    case $ANSWER in
        y)
            echo -e "\nNow starting the migration...\n"
        ;;
        n)
            echo -e "\nExiting.\n"
            exit 0
        ;;
        *)
            echo -e "\nInvalid answer. Please enter either 'y' or 'n'.\n"
            start_migration
        ;;
    esac
}

clean_up() {

    # Restoring original SLES-11-SP3-for-VMware product file
    rm /etc/products.d/SUSE_SLES.prod
    rm /etc/products.d/baseproduct
    mv /etc/products.d/SLES-for-VMware.prod.SLES-for-VMware /etc/products.d/SLES-for-VMware.prod
    ln -s /etc/products.d/SLES-for-VMware.prod /etc/products.d/baseproduct
}

start_migration

# Save the old 'SLES-for-VMware.prod' file of SLES-11-SP3-for-VMware and remove the
# symlink 'baseproduct'
rm /etc/products.d/baseproduct
mv /etc/products.d/SLES-for-VMware.prod /etc/products.d/SLES-for-VMware.prod.SLES-for-VMware


# Now create the new 'SUSE_SLES.prod' file for SLES-11-SP3
cat << EOT > /etc/products.d/SUSE_SLES.prod
<?xml version="1.0" encoding="UTF-8"?>
<product id="sle-11-server" schemeversion="0">
  <vendor>SUSE LINUX Products GmbH, Nuernberg, Germany</vendor>
  <name>SUSE_SLES</name>
  <version>11.3</version>
  <baseversion>11</baseversion>
  <patchlevel>3</patchlevel>
  <release>1.138</release>
  <arch>x86_64</arch>
  <productline>sles</productline>
  <register>
    <target>sle-11-x86_64</target>
    <release></release>
    <repositories>
      <repository path="obs://build.suse.de/SUSE:SLE-11-SP3:GA/standard" />
      <repository path="obs://build.suse.de/SUSE:SLE-11-SP2:Update/snapshot-SP3" />
      <repository path="obs://build.suse.de/SUSE:SLE-11-SP2:GA/standard" />
      <repository path="obs://build.suse.de/SUSE:SLE-11-SP1:Update/snapshot-SP3" />
      <repository path="obs://build.suse.de/SUSE:SLE-11-SP1:GA/standard" />
      <repository path="obs://build.suse.de/SUSE:SLE-11:Update/snapshot-SP3" />
      <repository path="obs://build.suse.de/SUSE:SLE-11:GA/standard" />
    </repositories>
  </register>
  <upgrades />
  <updaterepokey>A43242DKD</updaterepokey>
  <summary>SUSE Linux Enterprise Server 11 SP3</summary>
  <shortsummary>SLES11_SP3</shortsummary>
  <description>SUSE Linux Enterprise offers a comprehensive
        suite of products built on a single code base.
        The platform addresses business needs from
        the smallest thin-client devices to the world’s
        most powerful high-performance computing
        and mainframe servers. SUSE Linux Enterprise
        offers common management tools and technology
        certifications across the platform, and
        each product is enterprise-class.</description>
  <linguas>
    <language>cs</language>
    <language>da</language>
    <language>de</language>
    <language>en</language>
    <language>en_GB</language>
    <language>en_US</language>
    <language>es</language>
    <language>fi</language>
    <language>fr</language>
    <language>hu</language>
    <language>it</language>
    <language>ja</language>
    <language>nb</language>
    <language>nl</language>
    <language>pl</language>
    <language>pt</language>
    <language>pt_BR</language>
    <language>ru</language>
    <language>sv</language>
    <language>zh</language>
    <language>zh_CN</language>
    <language>zh_TW</language>
  </linguas>
  <urls>
    <url name="releasenotes">https://www.suse.com/releasenotes/x86_64/SUSE-SLES/11-SP3/release-notes-sles.rpm</url>
    <url name="smolt">http://smolt.novell.com/register.pl</url>
    <url name="register">http://register.novell.com/</url>
  </urls>
  <buildconfig>
    <producttheme>SLES</producttheme>
  </buildconfig>
  <installconfig>
    <defaultlang>en_US</defaultlang>
    <datadir>suse</datadir>
    <descriptiondir>suse/setup/descr</descriptiondir>
    <releasepackage name="sles-release" flag="EQ" version="11.3" release="1.138" />
    <distribution>SUSE_SLE</distribution>
  </installconfig>
  <runtimeconfig />
</product>
EOT

# Create the new 'baseproduct' symlink
ln -s /etc/products.d/SUSE_SLES.prod /etc/products.d/baseproduct

echo -e "\nNow registering. Please have all registration codes available.\n"

# Call 'suse_register' to subscribe to SLES-11-SP3 channels
if [ -x /usr/bin/suse_register ] ; then
    echo -e "delete old registration data\n"
    suse_register --erase-local-regdata
    echo -e "start registration\n"
    yast2 inst_suse_register
else
    echo -e "\n/usr/bin/suse_register is either not available or not executable.\n"
    echo -e "\nPlease install the package 'suseRegister' or ensure /usr/bin/suse_register is executable.\n"

    echo -e "\nRestoring original SLES-11-SP3-for-VMware product file.\n"
    clean_up

    echo -e "\nExiting.\n"
    exit 1
fi


# The release files need to be exchanged
echo -e "\nExchanging release packages...\n"
zypper -n in -f sles-release sles-release-DVD
zypper -n rm SLES-for-VMware-release SLES-for-VMware-release-DVD

echo -e "\nYou're now subscribed to following channels:\n"
zypper lr

echo -e "\nPress any key to continue...\n"
read KEY

# List of SLES-11-SP3 packages to be installed
SLES_PKGS+=" bootsplash-branding-SLES
 desktop-data-SLED
 desktop-data-SLES-extra-gnome
 gfxboot-branding-SLES
 MozillaFirefox-branding-SLED
 release-notes-sles
 yast2-branding-SLES
 yast2-theme-SLE"

# List of GNOME specific packages for SLES-11-SP3 to be installed
rpm -q gdm > /dev/null
if [ $? -eq 0 ] ; then
    SLES_PKGS+=" desktop-data-SLES-extra-gnome gconf2-branding-SLES gtk2-branding-SLED gtk2-theme-SLED"
fi

# List of KDE specific packages for SLES-11-SP3 to be installed
rpm -q kdm > /dev/null
if [ $? -eq 0 ] ; then
    SLES_PKGS+=" kdebase4-SLED kdebase4-SLED-lang kdebase4-workspace-branding-SLED kdm-branding-SLED"
fi


# Detect SLES-for-VMware specific packages
rpm -q bootsplash-branding-SLES-for-VMware > /dev/null
if [ $? -eq 0 ] ; then
    SLES_FOR_VMWARE_PKGS+=" bootsplash-branding-SLES-for-VMware"
fi

rpm -q  desktop-data-SLES-for-VMware> /dev/null
if [ $? -eq 0 ] ; then
    SLES_FOR_VMWARE_PKGS+=" desktop-data-SLES-for-VMware"
fi

rpm -q gconf2-branding-SLES-for-VMware > /dev/null
if [ $? -eq 0 ] ; then
    SLES_FOR_VMWARE_PKGS+=" gconf2-branding-SLES-for-VMware"
fi

rpm -q gfxboot-branding-SLES-for-VMware > /dev/null
if [ $? -eq 0 ] ; then
    SLES_FOR_VMWARE_PKGS+=" gfxboot-branding-SLES-for-VMware"
fi

rpm -q gtk2-branding-SLES-for-VMware > /dev/null
if [ $? -eq 0 ] ; then
    SLES_FOR_VMWARE_PKGS+=" gtk2-branding-SLES-for-VMware"
fi

rpm -q gtk2-theme-SLES-for-VMware > /dev/null
if [ $? -eq 0 ] ; then
    SLES_FOR_VMWARE_PKGS+=" gtk2-theme-SLES-for-VMware"
fi

rpm -q kdebase4-SLES-for-VMware > /dev/null
if [ $? -eq 0 ] ; then
    SLES_FOR_VMWARE_PKGS+=" kdebase4-SLES-for-VMware"
fi

rpm -q kdebase4-SLES-for-VMware-lang > /dev/null
if [ $? -eq 0 ] ; then
    SLES_FOR_VMWARE_PKGS+=" kdebase4-SLES-for-VMware-lang"
fi

rpm -q kdebase4-workspace-branding-SLES-for-VMware > /dev/null
if [ $? -eq 0 ] ; then
    SLES_FOR_VMWARE_PKGS+=" kdebase4-workspace-branding-SLES-for-VMware"
fi

rpm -q kdm-branding-SLES-for-VMware > /dev/null
if [ $? -eq 0 ] ; then
    SLES_FOR_VMWARE_PKGS+=" kdm-branding-SLES-for-VMware"
fi

rpm -q MozillaFirefox-branding-SLES-for-VMware > /dev/null
if [ $? -eq 0 ] ; then
    SLES_FOR_VMWARE_PKGS+=" MozillaFirefox-branding-SLES-for-VMware"
fi

rpm -q release-notes-SLES-for-VMware > /dev/null
if [ $? -eq 0 ] ; then
    SLES_FOR_VMWARE_PKGS+=" release-notes-SLES-for-VMware"
fi

rpm -q sblim-gather-novirt > /dev/null
if [ $? -eq 0 ] ; then
    SLES_FOR_VMWARE_PKGS+=" sblim-gather-novirt"
    SLES_PKGS+=" sblim-gather"
fi

rpm -q sblim-gather-novirt-provider > /dev/null
if [ $? -eq 0 ] ; then
    SLES_FOR_VMWARE_PKGS+=" sblim-gather-novirt-provider"
    SLES_PKGS+=" sblim-gather-provider"
fi

rpm -q yast2-branding-SLES-for-VMware > /dev/null
if [ $? -eq 0 ] ; then
    SLES_FOR_VMWARE_PKGS+=" yast2-branding-SLES-for-VMware"
fi

rpm -q yast2-theme-SLES-for-VMware > /dev/null
if [ $? -eq 0 ] ; then
    SLES_FOR_VMWARE_PKGS+=" yast2-theme-SLES-for-VMware"
fi

rpm -q yast2-trans-vmware-install > /dev/null
if [ $? -eq 0 ] ; then
    SLES_FOR_VMWARE_PKGS+=" yast2-trans-vmware-install"
fi

rpm -q yast2-vmware-warning > /dev/null
if [ $? -eq 0 ] ; then
    SLES_FOR_VMWARE_PKGS+=" yast2-vmware-warning"
fi

# Remove obsolete SLES-11-SP3-for-VMware specific packages
echo -e "\nRemoving obsolete SLES-11-SP3-for-VMware specific packages...\n"
zypper -n rm $SLES_FOR_VMWARE_PKGS

# Install missing SLES-11-SP3 packages
echo -e "\nInstall missing SLES-11-SP3 packages\n"
zypper -n in $SLES_PKGS


# Call 'mkinitrd' to apply the SLES-11-SP3 bootsplash branding
mkinitrd


# Adjust /boot/grub/menu.lst':
# --> Alter the titles of the standard and failsafe sections to display
#     "SUSE Linux Enterprise Server 11 SP3" instead of
#     "SUSE Linux Enterprise Server 11 SP3 for VMware"
sed "s/SUSE Linux Enterprise Server 11 SP3 for VMware/SUSE Linux Enterprise Server 11 SP3/" -i /boot/grub/menu.lst


# Reboot system to apply all changes
echo -e "\nPlease reboot your system so changes take effect.\n"
echo -e "\nDo you want to reboot now? [y/n]\n"

do_reboot() {

    read ANSWER

    case $ANSWER in
        y)
            echo -e "\nNow rebooting...\n"
	    reboot
        ;;
        n)
            echo -e "\nExiting.\n"
            exit 0
        ;;
        *)
            echo -e "\nInvalid answer. Please enter either 'y' or 'n'.\n"
	    do_reboot
        ;;
    esac
}

do_reboot

# EOF
